@@ -11,7 +11,6 @@ import (
 	"github.com/infracost/infracost/internal/ui"
 	"github.com/infracost/infracost/internal/update"
 	"github.com/infracost/infracost/internal/version"
-	"github.com/pkg/errors"
 	log "github.com/sirupsen/logrus"
 	"github.com/spf13/cobra"
 	"github.com/spf13/pflag"
@@ -84,6 +83,7 @@ func main() {
 	rootCmd.PersistentFlags().String("log-level", "", "Log level (trace, debug, info, warn, error, fatal)")
 
 	rootCmd.AddCommand(registerCmd(ctx))
+	rootCmd.AddCommand(configureCmd(ctx))
 	rootCmd.AddCommand(diffCmd(ctx))
 	rootCmd.AddCommand(breakdownCmd(ctx))
 	rootCmd.AddCommand(outputCmd(ctx))
@@ -140,10 +140,10 @@ func startUpdateCheck(ctx *config.RunContext, c chan *update.Info) {
 
 func checkAPIKey(apiKey string, apiEndpoint string, defaultEndpoint string) error {
 	if apiEndpoint == defaultEndpoint && apiKey == "" {
-		return errors.New(fmt.Sprintf(
+		return fmt.Errorf(
 			"No INFRACOST_API_KEY environment variable is set.\nWe run a free Cloud Pricing API, to get an API key run %s",
 			ui.PrimaryString("infracost register"),
-		))
+		)
 	}
 
 	return nil
@@ -209,10 +209,6 @@ func loadGlobalFlags(ctx *config.RunContext, cmd *cobra.Command) error {
 		}
 	}
 
-	if cmd.Flags().Changed("pricing-api-endpoint") {
-		ctx.Config.PricingAPIEndpoint, _ = cmd.Flags().GetString("pricing-api-endpoint")
-	}
-
 	ctx.SetContextValue("isDefaultPricingAPIEndpoint", ctx.Config.PricingAPIEndpoint == ctx.Config.DefaultPricingAPIEndpoint)
 
 	flagNames := make([]string, 0)
