@@ -44,6 +44,7 @@ func outputCmd(ctx *config.RunContext) *cobra.Command {
 			}
 
 			inputs := make([]output.ReportInput, 0, len(inputFiles))
+			currency := ""
 			for _, f := range inputFiles {
 				data, err := ioutil.ReadFile(f)
 				if err != nil {
@@ -59,6 +60,11 @@ func outputCmd(ctx *config.RunContext) *cobra.Command {
 					return fmt.Errorf("Invalid Infracost JSON file version. Supported versions are %s ≤ x ≤ %s", minOutputVersion, maxOutputVersion)
 				}
 
+				currency, err = checkCurrency(currency, j.Currency)
+				if err != nil {
+					return err
+				}
+
 				inputs = append(inputs, output.ReportInput{
 					Metadata: map[string]string{
 						"filename": f,
@@ -68,19 +74,21 @@ func outputCmd(ctx *config.RunContext) *cobra.Command {
 			}
 
 			format, _ := cmd.Flags().GetString("format")
-
+			includeAllFields := "all"
 			validFields := []string{"price", "monthlyQuantity", "unit", "hourlyCost", "monthlyCost"}
 
 			fields := []string{"monthlyQuantity", "unit", "monthlyCost"}
 			if cmd.Flags().Changed("fields") {
-				if c, _ := cmd.Flags().GetStringSlice("fields"); len(c) == 0 {
+				fields, _ = cmd.Flags().GetStringSlice("fields")
+				if len(fields) == 0 {
 					ui.PrintWarningf("fields is empty, using defaults: %s", cmd.Flag("fields").DefValue)
+				} else if len(fields) == 1 && fields[0] == includeAllFields {
+					fields = validFields
 				} else {
-					fields, _ = cmd.Flags().GetStringSlice("fields")
 					vf := []string{}
 					for _, f := range fields {
 						if !contains(validFields, f) {
-							ui.PrintWarningf("Invalid field '%s' specified, valid fields are: %s", f, validFields)
+							ui.PrintWarningf("Invalid field '%s' specified, valid fields are: %s or '%s' to include all fields", f, validFields, includeAllFields)
 						} else {
 							vf = append(vf, f)
 						}
@@ -98,7 +106,7 @@ func outputCmd(ctx *config.RunContext) *cobra.Command {
 			}
 			opts.ShowSkipped, _ = cmd.Flags().GetBool("show-skipped")
 
-			combined := output.Combine(inputs, opts)
+			combined := output.Combine(currency, inputs, opts)
 
 			var (
 				b   []byte
@@ -145,6 +153,23 @@ func outputCmd(ctx *config.RunContext) *cobra.Command {
 	return cmd
 }
 
+func checkCurrency(inputCurrency, fileCurrency string) (string, error) {
+	if fileCurrency == "" {
+		fileCurrency = "USD" // default to USD
+	}
+
+	if inputCurrency == "" {
+		// this must be the first file, save the input currency
+		inputCurrency = fileCurrency
+	}
+
+	if inputCurrency != fileCurrency {
+		return "", fmt.Errorf("Invalid Infracost JSON file currency mismatch.  Can't combine %s and %s", inputCurrency, fileCurrency)
+	}
+
+	return inputCurrency, nil
+}
+
 func checkOutputVersion(v string) bool {
 	if !strings.HasPrefix(v, "v") {
 		v = "v" + v
