@@ -2,6 +2,7 @@ package main
 
 import (
 	"fmt"
+	"github.com/Rhymond/go-money"
 	"os"
 	"strings"
 
@@ -145,6 +146,7 @@ func runMain(cmd *cobra.Command, runCtx *config.RunContext) error {
 	spinner.Success()
 
 	r := output.ToOutputFormat(projects)
+	r.Currency = runCtx.Config.Currency
 
 	var err error
 
@@ -258,20 +260,23 @@ func loadRunFlags(cfg *config.Config, cmd *cobra.Command) error {
 	cfg.ShowSkipped, _ = cmd.Flags().GetBool("show-skipped")
 	cfg.SyncUsageFile, _ = cmd.Flags().GetBool("sync-usage-file")
 
+	includeAllFields := "all"
 	validFields := []string{"price", "monthlyQuantity", "unit", "hourlyCost", "monthlyCost"}
 	validFieldsFormats := []string{"table", "html"}
 
 	if cmd.Flags().Changed("fields") {
-		if c, _ := cmd.Flags().GetStringSlice("fields"); len(c) == 0 {
+		fields, _ := cmd.Flags().GetStringSlice("fields")
+		if len(fields) == 0 {
 			ui.PrintWarningf("fields is empty, using defaults: %s", cmd.Flag("fields").DefValue)
 		} else if cfg.Fields != nil && !contains(validFieldsFormats, cfg.Format) {
 			ui.PrintWarning("fields is only supported for table and html output formats")
+		} else if len(fields) == 1 && fields[0] == includeAllFields {
+			cfg.Fields = validFields
 		} else {
-			fields, _ := cmd.Flags().GetStringSlice("fields")
 			vf := []string{}
 			for _, f := range fields {
 				if !contains(validFields, f) {
-					ui.PrintWarningf("Invalid field '%s' specified, valid fields are: %s", f, validFields)
+					ui.PrintWarningf("Invalid field '%s' specified, valid fields are: %s or '%s' to include all fields", f, validFields, includeAllFields)
 				} else {
 					vf = append(vf, f)
 				}
@@ -304,6 +309,11 @@ func checkRunConfig(cfg *config.Config) error {
 		}
 	}
 
+	if money.GetCurrency(cfg.Currency) == nil {
+		ui.PrintWarning(fmt.Sprintf("Ignoring unknown currency '%s', using USD.\n", cfg.Currency))
+		cfg.Currency = "USD"
+	}
+
 	return nil
 }
 
