@@ -24,7 +24,8 @@ type Project struct {
 }
 
 type Config struct {
-	Credentials Credentials
+	Credentials   Credentials
+	Configuration Configuration
 
 	Version         string `yaml:"version,omitempty" ignored:"true"`
 	LogLevel        string `yaml:"log_level,omitempty" envconfig:"INFRACOST_LOG_LEVEL"`
@@ -37,6 +38,8 @@ type Config struct {
 	DashboardAPIEndpoint      string `yaml:"dashboard_api_endpoint,omitempty" envconfig:"INFRACOST_DASHBOARD_API_ENDPOINT"`
 	EnableDashboard           bool   `yaml:"enable_dashboard,omitempty" envconfig:"INFRACOST_ENABLE_DASHBOARD"`
 
+	Currency string `envconfig:"INFRACOST_CURRENCY"`
+
 	Projects      []*Project `yaml:"projects" ignored:"true"`
 	Format        string     `yaml:"format,omitempty" ignored:"true"`
 	ShowSkipped   bool       `yaml:"show_skipped,omitempty" ignored:"true"`
@@ -100,6 +103,11 @@ func (c *Config) LoadFromEnv() error {
 		return err
 	}
 
+	err = loadConfiguration(c)
+	if err != nil {
+		return err
+	}
+
 	return nil
 }
 
